reviewpkg

package
v0.1.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 30, 2026 License: MIT Imports: 16 Imported by: 0

Documentation

Index

Constants

const ArtificialPhotosynthesisQuestion = "Do artificial photosynthesis catalysts improve solar fuel generation outcomes?"

Variables

This section is empty.

Functions

func Archive

func Archive(packagePath, archivePath string) error

func Restore

func Restore(archivePath, destination string) error

func WriteArtificialPhotosynthesisAcquisitionFixture added in v0.1.5

func WriteArtificialPhotosynthesisAcquisitionFixture(projectPath string) error

func WriteArtificialPhotosynthesisFixtureProject added in v0.1.5

func WriteArtificialPhotosynthesisFixtureProject(projectPath string) error

func WriteArtificialPhotosynthesisFixtureSourceImport added in v0.1.5

func WriteArtificialPhotosynthesisFixtureSourceImport(projectPath string) error

func WriteArtificialPhotosynthesisReferenceManagerFixture added in v0.1.5

func WriteArtificialPhotosynthesisReferenceManagerFixture(projectPath string) error

Types

type AuditCheck

type AuditCheck struct {
	Code    string `json:"code"`
	OK      bool   `json:"ok"`
	Message string `json:"message"`
}

type AuditReport

type AuditReport struct {
	SchemaVersion string       `json:"schemaVersion"`
	OK            bool         `json:"ok"`
	Checks        []AuditCheck `json:"checks"`
}

func Audit

func Audit(packagePath string) (AuditReport, error)

func Replay

func Replay(packagePath string) (AuditReport, error)

type Manifest

type Manifest struct {
	SchemaVersion              string   `json:"schemaVersion"`
	PackageID                  string   `json:"packageId"`
	CreatedAt                  string   `json:"createdAt"`
	CreatedBy                  string   `json:"createdBy"`
	ResearchForgeVersion       string   `json:"researchForgeVersion"`
	ProjectTitle               string   `json:"projectTitle,omitempty"`
	Question                   string   `json:"question,omitempty"`
	MetaAnalysisSpineVersion   string   `json:"metaAnalysisSpineVersion"`
	PackageRole                string   `json:"packageRole"`
	ProjectManifestRef         string   `json:"projectManifestRef"`
	SourcePlanRefs             []string `json:"sourcePlanRefs,omitempty"`
	LockfileRef                string   `json:"lockfileRef"`
	LockfileRefs               []string `json:"lockfileRefs,omitempty"`
	ProvenanceRef              string   `json:"provenanceRef,omitempty"`
	DedupeDecisionRef          string   `json:"dedupeDecisionRef,omitempty"`
	SourceRecordRefs           []string `json:"sourceRecordRefs,omitempty"`
	ImportReceiptRefs          []string `json:"importReceiptRefs,omitempty"`
	ReferenceManagerReportRefs []string `json:"referenceManagerReportRefs,omitempty"`
	LegalAcquisitionRef        string   `json:"legalAcquisitionRef,omitempty"`
	DocumentAssetRefs          []string `json:"documentAssetRefs,omitempty"`
	ScreeningAuditRef          string   `json:"screeningAuditRef,omitempty"`
	ExtractionSchemaRef        string   `json:"extractionSchemaRef,omitempty"`
	AcceptedEvidenceRef        string   `json:"acceptedEvidenceRef,omitempty"`
	ParserManifestRefs         []string `json:"parserManifestRefs,omitempty"`
	AnalysisArtifactRefs       []string `json:"analysisArtifactRefs,omitempty"`
	ReportRefs                 []string `json:"reportRefs,omitempty"`
	RedactionReportRef         string   `json:"redactionReportRef"`
	ChecksumManifestRef        string   `json:"checksumManifestRef"`
	ReplayCommand              string   `json:"replayCommand"`
	AuditCommand               string   `json:"auditCommand"`
	Warnings                   []string `json:"warnings,omitempty"`
}

type Options

type Options struct {
	CreatedBy string
	Question  string
	Clock     func() time.Time
}

type Package

type Package struct {
	Manifest        Manifest        `json:"manifest"`
	RedactionReport RedactionReport `json:"redactionReport"`
}

func Create

func Create(projectPath, packagePath string, opts Options) (Package, error)

func CreateArtificialPhotosynthesisFixturePackage added in v0.1.5

func CreateArtificialPhotosynthesisFixturePackage(packagePath string, opts Options) (Package, error)

CreateArtificialPhotosynthesisFixturePackage writes an offline, deterministic Reproducible review package using fake-backed Meta-analysis spine artifacts.

type RedactionItem

type RedactionItem struct {
	Path   string `json:"path"`
	Action string `json:"action"`
	Reason string `json:"reason"`
}

type RedactionReport

type RedactionReport struct {
	SchemaVersion string          `json:"schemaVersion"`
	Policy        string          `json:"policy"`
	Items         []RedactionItem `json:"items"`
}

Jump to