search

package
v0.1.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 30, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Concept

type Concept struct {
	Name     string
	Terms    []string
	Synonyms []string
}

Concept is one Boolean search concept with expansion terms.

type ConceptInput

type ConceptInput struct {
	Name     string
	Terms    []string
	Synonyms []string
}

ConceptInput is caller-provided concept metadata before normalization.

type FieldQuery

type FieldQuery struct {
	Field string
	Query string
}

FieldQuery stores a field-specific query fragment.

type Strategy

type Strategy struct {
	SchemaVersion string
	ID            string
	Title         string
	Concepts      []Concept
	Fields        []FieldQuery
	Schedule      WatchedSchedule
}

Strategy is a saved, versioned scholarly search strategy.

func NewStrategy

func NewStrategy(input StrategyInput) (Strategy, error)

NewStrategy validates and normalizes a saved search strategy.

func (Strategy) BooleanQuery

func (s Strategy) BooleanQuery() string

BooleanQuery renders concepts as OR groups joined by AND plus field-scoped clauses.

func (Strategy) ProvenanceMetadata

func (s Strategy) ProvenanceMetadata() map[string]string

ProvenanceMetadata returns stable metadata for provenance events that reference this strategy.

type StrategyInput

type StrategyInput struct {
	ID       string
	Title    string
	Concepts []ConceptInput
	Fields   []FieldQuery
	Schedule WatchedSchedule
}

StrategyInput is caller-provided search strategy metadata before normalization.

type WatchedSchedule

type WatchedSchedule struct {
	Enabled  bool
	Interval string
}

WatchedSchedule stores optional watched-search refresh metadata.

Jump to